@@ -3,6 +3,6 @@
 from .application import Application
 from .command import Command
 from .group import Group
-from .manpages import manpage_builder
+from .manpages import build_manpages
 
-__all__ = ["Application", "Command", "Group", "manpage_builder"]
+__all__ = ["Application", "Command", "Group", "build_manpages"]
